==> maxdb-all-linux-32bit-i386-7_5_00_38.tgz: SAPDB/Install/Base.pm <==
#!/usr/bin/perl
#
# $Header: //sapdb/V75/c_00/develop/sys/src/install/perl/SAPDB/Install/Base.pm#3 $
# $DateTime: 2003/12/11 13:40:27 $
# $Change: 59245 $
#
# Desc: 
#    ========== licence begin  GPL
#    Copyright (c) 2005 SAP AG
#
#    This program is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License
#    as published by the Free Software Foundation; either version 2
#    of the License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#    ========== licence end



package SAPDB::Install::Base;

#base class for all SAPDB::Install - Classes

sub BEGIN {
    @ISA=(SAPDB::Install::Exporter);
	@EXPORT=('main');
	my $repo = SAPDB::Install::Repository::GetCurrent ();
	my @neededPackages=(
		'StdIO',
		'Trace'
	);
	foreach my $package (@neededPackages){
	  	unless (defined $repo->Eval ("SAPDB::Install::$package", 1.01)) {
                print join ("\n", $repo->GetErr)."\n";
                die;
        	}
		SAPDB::Install::Exporter::import ("SAPDB::Install::$package"); 
	}
	
}


my %members=();


sub new{
	my $that = shift;
	my $class = ref($that) || $that;
	my $self ={
		%members,
	};
	my ($package,$file,$line) = caller;
	TraceMsg("create new object of class $package [in $file line $line]\n",4,\$DEBUG,3);
	bless $self,$class;
	return $self;
}

sub AUTOLOAD{
	my $self = shift;
	local *hash=$self;
	my $type = ref($self) || print2stderr("FATAL ERROR: \"$self\" is not an object \n") && diesoft($SAPDB::Install::Values::diemsg);
	my $name = $AUTOLOAD;
	my ($package,$file,$line) = caller;
	$name =~ s/.*://;
	$name =~ /destroy/i or exists $hash{$name} or print2stderr("FATAL ERROR: cannot access member \"$name\" of class \"$type\"\n") and diesoft($SAPDB::Install::Values::diemsg);
	if(@_){
		my $value = shift;
		if(exists $self->{'dirty'}){
			TraceMsg("dirty flag found in object\n",5,\$DEBUG,2);
			if(ref($value)){
				$value == $hash{$name} or $hash{'dirty'} = 1 and TraceMsg("set object dirty\n",5,\$DEBUG,2);
			}
			else{
				$value eq $hash{$name} or $hash{'dirty'} = 1 and TraceMsg("set object dirty\n",5,\$DEBUG,2);
			} 
		}
		exists $hash{'ID'} and my $id="(ID = ".$hash{'ID'}.")";
		TraceMsg("set $type$id->$name to $value [in $file line $line]\n",5,\$DEBUG,2);
		return $hash{$name} = $value;
	}
	else{
		exists $hash{'ID'} and my $id="(ID = ".$hash{'ID'}.")";
		TraceMsg("read $type$id->$name - value = ".$hash{$name}." [in $file line $line]\n",5,\$DEBUG,2);
		return $hash{$name};
	}
}

sub DESTROY{
	my ($self)=@_;
	my ($package,$file,$line) = caller;
	exists ${%$self}{'ID'} and my $id="(ID = ".${%$self}{'ID'}.")";
	TraceMsg("destroy an object of class $package $id\n",4,\$DEBUG,2);
}


1;

==> maxdb-all-linux-32bit-i386-7_6_02_10.tgz: SAPDB/Install/Base.pm <==
#!/usr/bin/perl
#
# $Header: //sapdb/V76/c_02/b_10/sys/src/install/perl/SAPDB/Install/Base.pm#1 $
# $DateTime: 2007/03/28 16:58:41 $
# $Change: 148814 $
#
# Desc: 

package SAPDB::Install::Base;

#base class for all SAPDB::Install - Classes

require SDB::Common::Exporter;
our @ISA = qw (SDB::Common::Exporter);
our @EXPORT = qw (main);

use SAPDB::Install::StdIO;
use SAPDB::Install::Trace;

my %members=();


sub new{
	my $that = shift;
	my $class = ref($that) || $that;
	my $self ={
		%members,
	};
	my ($package,$file,$line) = caller;
	TraceMsg("create new object of class $package [in $file line $line]\n",4,\$DEBUG,3);
	bless $self,$class;
	return $self;
}

sub AUTOLOAD{
	my $self = shift;
	local *hash=$self;
	my ($package,$file,$line) = caller;
	my $type = ref($self) || print2stderr("FATAL ERROR: $AUTOLOAD(), \"$self\" is not an object, package: $package, file: $file, line: $line\n") && diesoft($SAPDB::Install::Values::diemsg);
	my $name = $AUTOLOAD;
	$name =~ s/.*://;

	$name =~ /destroy/i or exists $hash{$name} or print2stderr("FATAL ERROR: cannot access member \"$name\" of class \"$type\", package: $package, file: $file, line: $line\n") and diesoft($SAPDB::Install::Values::diemsg);
	if(@_){
		my $value = shift;
		if(exists $self->{'dirty'}){
			TraceMsg("dirty flag found in object\n",5,\$DEBUG,2);
			if(ref($value)){
				$value == $hash{$name} or $hash{'dirty'} = 1 and TraceMsg("set object dirty\n",5,\$DEBUG,2);
			}
			else{
				$value eq $hash{$name} or $hash{'dirty'} = 1 and TraceMsg("set object dirty\n",5,\$DEBUG,2);
			} 
		}
		exists $hash{'ID'} and my $id="(ID = ".$hash{'ID'}.")";
		TraceMsg("set $type$id->$name to $value [in $file line $line]\n",5,\$DEBUG,2);
		return $hash{$name} = $value;
	}
	else{
		exists $hash{'ID'} and my $id="(ID = ".$hash{'ID'}.")";
		TraceMsg("read $type$id->$name - value = ".$hash{$name}." [in $file line $line]\n",5,\$DEBUG,2);
		return $hash{$name};
	}
}

sub DESTROY{
	my ($self)=@_;
	my ($package,$file,$line) = caller;
	exists ${%$self}{'ID'} and my $id="(ID = ".${%$self}{'ID'}.")";
	TraceMsg("destroy an object of class $package $id\n",4,\$DEBUG,2);
}


1;
